import { useCallback, useEffect, useState } from 'react';
import { receiveCredentialFromOpenId4VciOffer } from '../resolver';
import { DeviceEventEmitter } from 'react-native';
import { EventTypes } from '../../../constants';
import { BifoldError } from '../../../types/error';
import { useAgent } from '@credo-ts/react-hooks';
import { useTranslation } from 'react-i18next';
export const useOpenID = ({
  openIDUri
}) => {
  const [openIdRecord, setOpenIdRecord] = useState();
  const {
    agent
  } = useAgent();
  const {
    t
  } = useTranslation();
  const resolveOpenIDCredential = useCallback(async uri => {
    if (!agent) {
      return;
    }
    try {
      const record = await receiveCredentialFromOpenId4VciOffer({
        agent: agent,
        uri: uri
      });
      return record;
    } catch (err) {
      //TODO: Sppecify different error
      const error = new BifoldError(t('Error.Title1043'), t('Error.Message1043'), (err === null || err === void 0 ? void 0 : err.message) ?? err, 1043);
      DeviceEventEmitter.emit(EventTypes.ERROR_ADDED, error);
    }
  }, [agent, t]);
  useEffect(() => {
    if (!openIDUri) {
      return;
    }
    resolveOpenIDCredential(openIDUri).then(value => {
      if (value) {
        setOpenIdRecord(value);
      }
    });
  }, [openIDUri, resolveOpenIDCredential]);
  return openIdRecord;
};
//# sourceMappingURL=openid.js.map